@@ -3,7 +3,6 @@
 from trytond.model import (ModelView, ModelSQL, MatchMixin, fields,
     sequence_ordered)
 from trytond.pyson import If, Eval, Bool
-from trytond import backend
 from trytond.pool import PoolMeta
 
 __all__ = ['ProductLocation', 'Move', 'ShipmentIn', 'ShipmentOutReturn']
@@ -27,19 +26,8 @@ class ProductLocation(sequence_ordered(), ModelSQL, ModelView, MatchMixin):
                     [Eval('warehouse')], [])),
             ], depends=['warehouse'])
 
-    @classmethod
-    def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        table = TableHandler(cls, module_name)
 
-        super(ProductLocation, cls).__register__(module_name)
-
-        # Migration from 2.4: drop required on sequence
-        table.not_null_action('sequence', action='remove')
-
-
-class Move:
-    __metaclass__ = PoolMeta
+class Move(metaclass=PoolMeta):
     __name__ = 'stock.move'
 
     def set_product_location(self, field='to_location', **pattern):
@@ -53,8 +41,7 @@ class Move:
                 break
 
 
-class ShipmentIn:
-    __metaclass__ = PoolMeta
+class ShipmentIn(metaclass=PoolMeta):
     __name__ = 'stock.shipment.in'
 
     @classmethod
@@ -66,8 +53,7 @@ class ShipmentIn:
         return move
 
 
-class ShipmentOutReturn:
-    __metaclass__ = PoolMeta
+class ShipmentOutReturn(metaclass=PoolMeta):
     __name__ = 'stock.shipment.out.return'
 
     @classmethod
